Function one_compartment_cl
pub fn one_compartment_cl(
x: &NalgebraVec<f64>,
p: &NalgebraVec<f64>,
t: f64,
rateiv: &NalgebraVec<f64>,
cov: &Covariates,
) -> NalgebraVec<f64>Expand description
Analytical solution for one compartment model parameterized by clearance.
Converts CL/V to ke and delegates to one_compartment.
Assumptions
pis a vector of length 2 with CL and V in that orderrateivis a vector of length 1 with the value of the infusion rate (only one drug)xis a vector of length 1- covariates are not used