Struct Analytical
pub struct Analytical { /* private fields */ }Expand description
Model equation using analytical solutions.
This implementation uses closed-form analytical solutions for the model equations rather than numerical integration.
Implementations
impl Analytical
impl Analytical
pub fn new(
eq: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &NalgebraVec<f64>, &Covariates) -> NalgebraVec<f64>,
seq_eq: fn(&mut NalgebraVec<f64>, f64, &Covariates),
lag: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>,
fa: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>,
init: fn(&NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>),
out: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>),
) -> Analytical
pub fn new( eq: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &NalgebraVec<f64>, &Covariates) -> NalgebraVec<f64>, seq_eq: fn(&mut NalgebraVec<f64>, f64, &Covariates), lag: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>, fa: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>, init: fn(&NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>), out: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>), ) -> Analytical
Create a new Analytical equation model with default Neqs (all sizes = 5).
Use builder methods to configure dimensions:
ⓘ
Analytical::new(eq, seq_eq, lag, fa, init, out)
.with_nstates(2)
.with_ndrugs(1)
.with_nout(1)pub fn with_nstates(self, nstates: usize) -> Analytical
pub fn with_nstates(self, nstates: usize) -> Analytical
Set the number of state variables.
pub fn with_ndrugs(self, ndrugs: usize) -> Analytical
pub fn with_ndrugs(self, ndrugs: usize) -> Analytical
Set the number of drug input channels (size of bolus[] and rateiv[]).
pub fn with_nout(self, nout: usize) -> Analytical
pub fn with_nout(self, nout: usize) -> Analytical
Set the number of output equations.